@@ -143,14 +143,17 @@ struct _PangoFcFontMapClass
   void (*_pango_reserved4) (void);
 };
 
+#ifndef PANGO_DISABLE_DEPRECATED
 PangoContext * pango_fc_font_map_create_context (PangoFcFontMap *fcfontmap);
-void           pango_fc_font_map_cache_clear    (PangoFcFontMap *fcfontmap);
+#endif
 void           pango_fc_font_map_shutdown       (PangoFcFontMap *fcfontmap);
 
 #endif
 
 GType pango_fc_font_map_get_type (void) G_GNUC_CONST;
 
+void           pango_fc_font_map_cache_clear    (PangoFcFontMap *fcfontmap);
+
 /**
  * PangoFcDecoderFindFunc:
  * @pattern: a fully resolved #FcPattern specifying the font on the system
@@ -191,8 +194,8 @@ PangoFontDescription *pango_fc_font_description_from_pattern (FcPattern *pattern
  * String representing a fontconfig property name that Pango sets on any
  * fontconfig pattern it passes to fontconfig.
  *
- * The property will have an integer value equal to what pango_version()
- * returns.
+ * The property will have an integer value equal to what
+ * pango_version() returns.
  *
  * Since: 1.20
  */
